Option Explicit

' Constantes (accs fichiers : lecture / ecriture)
Const vbForReading                  = 1
Const vbForWriting                  = 2
Const vbForAppend                   = 8

'--------------------------------------------------------------------------
' Fonction appele pour remplacer un texte par un autre.
' Ceci utilise les expressions rgulres et permet donc de faire des
' rechercher / remplacer complexes.
' Voir la documentation MFC - RegExp => VBScript => Pattern property
'
' Paramtres :
'-------------
'   strToReplace : Chaine dans laquelle trouver les lements  remplacer.
'   strPattern   : Pattern  trouver dans la chane.
'   strReplaceBy : Remplacer les occurences par cette chaine.
'   bIgnoreCase  : Permet d'ignorer la casse (si = True) ou pas.
'   bGlobal      : Indique s'il faut faire un seul remplacement ou tous les remplacements possibles
'
' Retour :
'---------
'   La chaine dont toutes les occurences sont remplaces
'--------------------------------------------------------------------------
Function ReplaceText(strToReplace, strPattern, strReplaceBy, bIgnoreCase, bGlobal)
    Dim regEx                       ' Variable contenant l'expression rgulire
    Set regEx = New RegExp          ' Creation de l'expression rgulire
    regEx.IgnoreCase = bIgnoreCase  ' Ignorer la casse ou pas
    regEx.Global  = bGlobal         ' Multiples remplacements (global)
    regEx.Pattern = strPattern      ' Initialisation du pattern
    ReplaceText = regEx.Replace(strToReplace, strReplaceBy)   ' Make replacement.
    Set regEx = Nothing
End Function

'--------------------------------------------------------------------------
' Fonction appele pour rechercher du texte
' Ceci utilise les expressions rgulres et permet donc de faire des
' rechercher complexes.
' Voir la documentation MFC - RegExp => VBScript => Pattern property
'
' Paramtres :
'-------------
'   strToFind    : Chaine dans laquelle trouver les lements.
'   strPattern   : Pattern  trouver dans la chane.
'   bIgnoreCase  : Permet d'ignorer la casse (si = True) ou pas.
'   bGlobal      : Indique s'il faut faire une recherche globale ou s'arrter  la premire
'
' Retour :
'---------
'   Un tableau de chaine avec toutes les occurences trouves.
'   Pour le parcourir :
'       Set arrayMatchs = FindText(paramtres)
'       ' Iterate Matches collection.
'       For Each match in arrayMatchs
'           value = match.SubMatches(0)  'Match valeur (ou autre selon les parenthses dans l'expression rgulire)
'       Next
'   Pour savoir combien d'lment il contient :
'       Set arrayMatchs = FindText(paramtres)
'       If arrayMatchs.Count > 0 Then
'           - code -
'       End If
'--------------------------------------------------------------------------
Function FindText(strToFind, strPattern, bIgnoreCase, bGlobal)
    Dim regEx                               ' Variable contenant l'expression rgulire
    Set regEx = New RegExp                  ' Creation de l'expression rgulire
    regEx.IgnoreCase = bIgnoreCase          ' Ignorer la casse ou pas
    regEx.Global  = bGlobal                 ' Multiples remplacements (global)
    regEx.Pattern = strPattern              ' Initialisation du pattern
    Set FindText = regEx.Execute(strToFind) ' Execute search.
End Function

'--------------------------------------------------------------------------
' Ajout d'un chemin avec un autre cheminb ou nom de fichier.
'
' Gre les \ afin que les chemins se composent correctement.
'
' Paramtres :
'-------------
'   strPath         : Chaine dans laquelle trouver les lements  remplacer.
'   strPathOrFile   : Pattern  trouver dans la chane.
'
' Retour :
'---------
'   Le chemin complt.
'--------------------------------------------------------------------------
Function AddPath(strPath, strPathOrFile)
    ' Ajouter \ si n'existe pas  la fin du chemin
    If Len(strPath) > 0 Then
        If Right(strPath,1) <> "\" And Right(strPath,1) <> "/" Then
            strPath = strPath & "\"
        End If
    End If

    ' Supprimer / si existe au dbut du fichier
    If Len(strPathOrFile) > 0 Then
        If Left(strPathOrFile,1) = "\" Or Right(strPathOrFile,1) = "/" Then
            strPathOrFile = Right(strPathOrFile,Len(strPathOrFile) - 1)
        End If
    End If
    AddPath = strPath & strPathOrFile
End Function

'--------------------------------------------------------------------------
' Rcuprer le chamin sans le nom de fichier.
'
' Tient compte de \ ou /, les deux sont dtects.
'
' Paramtres :
'-------------
'   strPathName : Chemin + Nom de fichier
'
' Retour :
'---------
'   Le chemin du rpertoire du chemin pass en paramtre.
'
'--------------------------------------------------------------------------
Function GetPath(strPathName)
    Dim strCopyPathName
    strCopyPathName = Replace(strPathName,"/","\",1,-1,vbTextCompare)
    GetPath = Left(strPathName,InStrRev(strCopyPathName,"\",-1,vbTextCompare))
End Function

'--------------------------------------------------------------------------
' Rcuprer le chamin d'o est lanc le script
'
' Paramtres :
'-------------
'   aucun
'
' Retour :
'---------
'   Le chemin du rpertoire d'o est lanc le script.
'
'--------------------------------------------------------------------------
Function GetCurrentPath()
    GetCurrentPath = GetPath(WScript.ScriptFullName)
End Function

'--------------------------------------------------------------------------
' Lit un fichier depuis le disque.
'
' Paramtres :
'-------------
'   strFilePath  : Chemin du fichier  lire.
'
' Retour :
'---------
'   Une chaine contenant tout le fichier lu depuis le disque.
'   Une erreur se produit si le fichier n'existe pas, vrifier avant
'   de le lire qu'il est bien prsent sur le disque.
'
' Voir aussi :
'-------------
'   Voir WriteFile,FileExists,FileAttribs,WriteFileAttribs,DeleteFile,MoveFile
'--------------------------------------------------------------------------
Function ReadFile(strFilePath)
    Dim fileObject, file

    Set fileObject = CreateObject("Scripting.FileSystemObject")
    Set file = fileObject.OpenTextFile(strFilePath,vbForReading)

    On Error Resume Next ' Si erreur, continuer
    ReadFile = file.ReadAll()
    If Err.number<>0 Then
        If Err.number = 62 Then
            ' On a tent de lire un fichier vide : bizarre, l'erreur 62 dans MSDN = ERROR_NO_SPOOL_SPACE : Space to store the file waiting to be printed is not available on the server
            ReadFile = ""
            Call Err.Clear()
        Else
            On Error Goto 0
            ReadFile = file.ReadAll()
        End If
    End If
    On Error Goto 0

    Set file       = Nothing
    Set fileObject = Nothing
End Function

'--------------------------------------------------------------------------
' Ecrit un fichier sur le disque.
'
' Paramtres :
'-------------
'   strFilePath  : Chemin du fichier  crire.
'   strContent   : Contenu du fichier  crire dans celui-ci.
'
' Retour :
'---------
'   La valeur de retour de la fonction Write de Scripting.FileSystemObject,
'   0 si pas d'erreur
'
' Voir aussi :
'-------------
'   Voir ReadFile,FileExists,FileAttribs,WriteFileAttribs,DeleteFile,CopyFile,MoveFile
'--------------------------------------------------------------------------
Function WriteFile(strFilePath,strContent)
    Dim fileObject, file

    WriteFile = 0
    Set fileObject = CreateObject("Scripting.FileSystemObject")
    On Error Resume Next
    Set file = fileObject.OpenTextFile(strFilePath,vbForWriting,True)
    If Err.number<>0 Then
        ' Si erreur (ficher en lecture seule, nom de fichier incorrect, etc...)
        WriteFile = Err.number
        Call Err.Clear()
    Else
        WriteFile = file.Write(strContent)

        If Err.number<>0 Then
            WriteFile = Err.number
        Else
            Call file.Close()
            If Err.number<>0 Then
                WriteFile = Err.number
            End If
        End If
    End If
    On Error Goto 0
    Set file       = Nothing
    Set fileObject = Nothing
End Function

If WSCript.Arguments.Length <> 1 Then
    Call MsgBox("Erreur, un argument est ncessaire gnrer le .def !", vbOKOnly + vbCritical + vbSystemModal, "Erreur de gnration !")
    WScript.Quit -1
End If

Dim strFileContent, strData, arrayMatchs, ObjFso, ObjFile, iError, iRet, strFullPath

strFullPath = WSCript.Arguments(0)
iRet = 0
Set ObjFso = CreateObject("Scripting.FileSystemObject")
Set ObjFile = ObjFso.OpenTextFile(strFullPath)

strFileContent = "LIBRARY " & Mid(strFullPath, Len(GetPath(strFullPath)) + 1, Len(strFullPath) - Len(GetPath(strFullPath)) - Len(".dll.export")) & ".dll" & vbCrLf & "EXPORTS" & vbCrLf
Do Until ObjFile.AtEndOfStream
    strData = ObjFile.ReadLine
    Set arrayMatchs = FindText(strData, "^ +[0-9]+ +[0-9A-F]+ [0-9A-F]+ [_A-Za-z0-9]+", False, True)
    If arrayMatchs.Count > 0 Then
      ' strFileContent = strFileContent & ReplaceText(strData, "^ +[0-9]+ +[0-9A-F]+ [0-9A-F]+ ?([_A-Za-z0-9]+).*$", "$1", False, True) & VbCrlf              ' _HwdContextGetHwdRootPath
      ' strFileContent = strFileContent & ReplaceText(strData, "^ +[0-9]+ +[0-9A-F]+ [0-9A-F]+ (?:_+)?([_A-Za-z0-9]+).*$", "$1", False, True) & VbCrlf        ' HwdContextGetHwdRootPath
        strFileContent = strFileContent & ReplaceText(strData, "^ +[0-9]+ +[0-9A-F]+ [0-9A-F]+ ?([_A-Za-z0-9@]+).*$", "$1", False, True) & VbCrlf             ' _HwdContextGetHwdRootPath@0
      ' strFileContent = strFileContent & ReplaceText(strData, "^ +[0-9]+ +[0-9A-F]+ [0-9A-F]+ (?:_+)?([_A-Za-z0-9@]+).*$", "$1", False, True) & VbCrlf       ' HwdContextGetHwdRootPath@0
    End If
Loop

Set ObjFile = Nothing
Set ObjFso  = Nothing

iError = WriteFile(Mid(strFullPath, 1, Len(strFullPath) - Len(".dll.export")) & ".def", strFileContent)
If iError <> 0 Then
    Call MsgBox("Erreur lors de l'criture = " & iError, vbOKOnly + vbCritical + vbSystemModal, "Erreur de gnration !")
    iRet = -1
End If

WScript.Quit iRet